@@ -35,14 +35,15 @@
 #include <QCompleter>
 #include <QFileSystemModel>
 #include <QtCore/QUrl>
+#include <QFontDialog>
+#include <QFileDialog>
+#include <QInputDialog>
+#include <QDialog>
 #include <QDebug>
 // KDE
-#include <kdeversion.h>
 #include <KCodecAction>
 
-#include <KFontDialog>
 #include <KIconDialog>
-#include <KFileDialog>
 #include <KUrlCompletion>
 #include <KWindowSystem>
 #include <KTextEdit>
@@ -329,25 +330,20 @@ void EditProfileDialog::setupGeneralPage(const Profile::Ptr profile)
 }
 void EditProfileDialog::showEnvironmentEditor()
 {
+    bool ok;
     const Profile::Ptr profile = lookupProfile();
-
-    QWeakPointer<KDialog> dialog = new KDialog(this);
-    KTextEdit* edit = new KTextEdit(dialog.data());
-
     QStringList currentEnvironment = profile->environment();
 
-    edit->setPlainText(currentEnvironment.join("\n"));
-    edit->setToolTip(i18nc("@info:tooltip", "One environment variable per line"));
+    QString text = QInputDialog::getMultiLineText(this, 
+            i18n("Edit Environment"),
+            i18n("One environment variable per line"),
+            currentEnvironment.join("\n"),
+            &ok);
 
-    dialog.data()->setPlainCaption(i18n("Edit Environment"));
-    dialog.data()->setMainWidget(edit);
-
-    if (dialog.data()->exec() == QDialog::Accepted) {
-        QStringList newEnvironment = edit->toPlainText().split('\n');
+    if (ok && !text.isEmpty()) {
+        QStringList newEnvironment = text.split('\n');
         updateTempProfileProperty(Profile::Environment, newEnvironment);
     }
-
-    delete dialog.data();
 }
 void EditProfileDialog::setupTabsPage(const Profile::Ptr profile)
 {
@@ -426,9 +422,9 @@ void EditProfileDialog::commandChanged(const QString& command)
 }
 void EditProfileDialog::selectInitialDir()
 {
-    const QUrl url = KFileDialog::getExistingDirectoryUrl(QUrl::fromUserInput(_ui->initialDirEdit->text()),
-                     this,
-                     i18n("Select Initial Directory"));
+    const QUrl url = QFileDialog::getExistingDirectoryUrl(this,
+                     i18n("Select Initial Directory"),
+                     QUrl::fromUserInput(_ui->initialDirEdit->text()));
 
     if (!url.isEmpty())
         _ui->initialDirEdit->setText(url.path());
@@ -883,15 +879,18 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
 
     Q_ASSERT(translator);
 
-    QWeakPointer<KDialog> dialog = new KDialog(this);
+    QDialog dialog(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(&dialog);
+    buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    connect(buttonBox, SIGNAL(accepted()), &dialog, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), &dialog, SLOT(reject()));
 
     if (isNewTranslator)
-        dialog.data()->setWindowTitle(i18n("New Key Binding List"));
+        dialog.setWindowTitle(i18n("New Key Binding List"));
     else
-        dialog.data()->setWindowTitle(i18n("Edit Key Binding List"));
+        dialog.setWindowTitle(i18n("Edit Key Binding List"));
 
     KeyBindingEditor* editor = new KeyBindingEditor;
-    dialog.data()->setMainWidget(editor);
 
     if (translator)
         editor->setup(translator);
@@ -899,7 +898,12 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
     if (isNewTranslator)
         editor->setDescription(i18n("New Key Binding List"));
 
-    if (dialog.data()->exec() == QDialog::Accepted) {
+    QVBoxLayout *layout = new QVBoxLayout;
+    layout->addWidget(editor);
+    layout->addWidget(buttonBox);
+    dialog.setLayout(layout);
+
+    if (dialog.exec() == QDialog::Accepted) {
         KeyboardTranslator* newTranslator = new KeyboardTranslator(*editor->translator());
 
         if (isNewTranslator)
@@ -916,7 +920,6 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
             updateTempProfileProperty(Profile::KeyBindings, newTranslator->name());
         }
     }
-    delete dialog.data();
 }
 void EditProfileDialog::newKeyBinding()
 {
@@ -1211,30 +1214,15 @@ void EditProfileDialog::fontSelected(const QFont& aFont)
 }
 void EditProfileDialog::showFontDialog()
 {
-    QString sampleText = QString("ell 'lL', one '1', little eye 'i', big eye");
-    sampleText += QString("'I', lL1iI, Zero '0', little oh 'o', big oh 'O', 0oO");
-    sampleText += QString("`~!@#$%^&*()_+-=[]\\{}|:\";'<>?,./");
-    sampleText += QString("0123456789");
-    sampleText += QString("\nThe Quick Brown Fox Jumps Over The Lazy Dog\n");
-    sampleText += i18n("--- Type anything in this box ---");
     QFont currentFont = _ui->fontPreviewLabel->font();
 
-    QWeakPointer<KFontDialog> dialog = new KFontDialog(this, KFontChooser::FixedFontsOnly);
-    dialog.data()->setWindowTitle(i18n("Select Fixed Width Font"));
-    dialog.data()->setFont(currentFont, true);
+    bool result;
+    currentFont = QFontDialog::getFont(&result, currentFont, this,
+                                       i18n("Select Fixed Width Font"),
+                                       QFontDialog::MonospacedFonts);
+    if (!result) return;
 
-    // TODO (hindenburg): When https://git.reviewboard.kde.org/r/103357 is
-    // committed, change the below.
-    // Use text more fitting to show font differences in a terminal
-    QList<KFontChooser*> chooserList = dialog.data()->findChildren<KFontChooser*>();
-    if (!chooserList.isEmpty())
-        chooserList.at(0)->setSampleText(sampleText);
-
-    connect(dialog.data(), &KFontDialog::fontSelected, this, &Konsole::EditProfileDialog::fontSelected);
-
-    if (dialog.data()->exec() == QDialog::Rejected)
-        fontSelected(currentFont);
-    delete dialog.data();
+    fontSelected(currentFont);
 }
 void EditProfileDialog::setFontSize(double pointSize)
 {
