@@ -28,6 +28,7 @@
 #include <QtGui/QKeyEvent>
 #include <QPrinter>
 #include <QPrintDialog>
+#include <QFileDialog>
 #include <QPainter>
 #include <QStandardPaths>
 #include <QtCore/QUrl>
@@ -71,7 +72,6 @@
 #include "PrintOptions.h"
 
 // for SaveHistoryTask
-#include <KFileDialog>
 #include <KIO/Job>
 #include <KJob>
 #include "TerminalCharacterDecoder.h"
@@ -1575,9 +1575,10 @@ void SessionController::zmodemDownload()
         zmodem = QStandardPaths::findExecutable("lrz");
     }
     if (!zmodem.isEmpty()) {
-        const QString path = KFileDialog::getExistingDirectory(
-                                 QUrl(), _view,
-                                 i18n("Save ZModem Download to..."));
+        const QString path = QFileDialog::getExistingDirectory(_view,
+                i18n("Save ZModem Download to ..."),
+                QDir::homePath(),
+                QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
 
         if (!path.isEmpty()) {
             _session->startZModem(zmodem, path, QStringList());
@@ -1611,8 +1612,9 @@ void SessionController::zmodemUpload()
         return;
     }
 
-    QStringList files = KFileDialog::getOpenFileNames(QUrl(), QString(), _view,
-                        i18n("Select Files for ZModem Upload"));
+    QStringList files = QFileDialog::getOpenFileNames(_view,
+                        i18n("Select Files for ZModem Upload"),
+                        QDir::homePath());
     if (!files.isEmpty()) {
         _session->startZModem(zmodem, QString(), files);
     }
@@ -1663,17 +1665,14 @@ void SaveHistoryTask::execute()
     //        three then providing a URL for each one will be tedious
 
     // TODO - show a warning ( preferably passive ) if saving the history output fails
-    //
-
-    KFileDialog* dialog = new KFileDialog(QUrl(QString(":konsole")) /* check this */,
-                                          QString(), QApplication::activeWindow());
-    dialog->setOperationMode(KFileDialog::Saving);
-    dialog->setConfirmOverwrite(true);
+    QFileDialog* dialog = new QFileDialog(QApplication::activeWindow(),
+            QString(),
+            QDir::homePath());
 
     QStringList mimeTypes;
     mimeTypes << "text/plain";
     mimeTypes << "text/html";
-    dialog->setMimeFilter(mimeTypes, "text/plain");
+    dialog->setMimeTypeFilters(mimeTypes);
 
     // iterate over each session in the task and display a dialog to allow the user to choose where
     // to save that session's history.
@@ -1686,7 +1685,7 @@ void SaveHistoryTask::execute()
         if (result != QDialog::Accepted)
             continue;
 
-        QUrl url = dialog->selectedUrl();
+        QUrl url = (dialog->selectedUrls()).at(0);
 
         if (!url.isValid()) {
             // UI:  Can we make this friendlier?
@@ -1716,7 +1715,7 @@ void SaveHistoryTask::execute()
         // from.
         // this is set to -1 to indicate the job has just been started
 
-        if (dialog->currentMimeFilter() == "text/html")
+        if ((dialog->mimeTypeFilters()).contains("text/html"), Qt::CaseInsensitive)
             jobInfo.decoder = new HTMLDecoder();
         else
             jobInfo.decoder = new PlainTextDecoder();
