@@ -22,29 +22,41 @@
 // KDE
 #include <KLocalizedString>
 #include <KTextEdit>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <KGuiItem>
+#include <QVBoxLayout>
 
 using Konsole::ZModemDialog;
 
 ZModemDialog::ZModemDialog(QWidget* aParent, bool modal, const QString& caption)
-    : KDialog(aParent)
+    : QDialog(aParent)
 {
     setObjectName(QLatin1String("zmodem_progress"));
     setModal(modal);
-    setCaption(caption);
+    setWindowTitle(caption);
 
-    setButtons(KDialog::User1 | KDialog::Close);
-    setButtonGuiItem(KDialog::User1, KGuiItem(i18n("&Stop")));
-    setDefaultButton(KDialog::Close);
-    setEscapeButton(KDialog::User1);
-    enableButton(KDialog::Close, false);
+    mButtonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    mUser1Button = new QPushButton;
+    mButtonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
+    mainLayout->addWidget(mButtonBox);
+    KGuiItem::assign(mUser1Button, KGuiItem(i18n("&Stop")));
+    mButtonBox->button(QDialogButtonBox::Close)->setDefault(true);
+    mUser1Button->setShortcut(Qt::Key_Escape);
+    mButtonBox->button(QDialogButtonBox::Close)->setEnabled(false);
 
     _textEdit = new KTextEdit(this);
     _textEdit->setMinimumSize(400, 100);
     _textEdit->setReadOnly(true);
-    setMainWidget(_textEdit);
+    mainLayout->addWidget(_textEdit);
 
-    connect(this, SIGNAL(user1Clicked()), this, SLOT(slotClose()));
-    connect(this, SIGNAL(closeClicked()), this, SLOT(slotClose()));
+    connect(this, &Konsole::ZModemDialog::user1Clicked, this, &Konsole::ZModemDialog::slotUser1Clicked);
+    connect(mButtonBox->button(QDialogButtonBox::Close), &QPushButton::clicked, this, &Konsole::ZModemDialog::slotClose);
 }
 
 void ZModemDialog::addProgressText(const QString& text)
@@ -55,10 +67,16 @@ void ZModemDialog::addProgressText(const QString& text)
     currentCursor.insertText(text);
 }
 
+void ZModemDialog::slotUser1Clicked()
+{
+    Q_EMIT user1Clicked();
+    slotClose();
+}
+
 void ZModemDialog::transferDone()
 {
-    enableButton(KDialog::Close, true);
-    enableButton(KDialog::User1, false);
+    mButtonBox->button(QDialogButtonBox::Close)->setEnabled(true);
+    mUser1Button->setEnabled(false);
 }
 
 void ZModemDialog::slotClose()
@@ -67,4 +85,11 @@ void ZModemDialog::slotClose()
     accept();
 }
 
-#include "ZModemDialog.moc"
+void ZModemDialog::delayedDestruct()
+{
+    if (isVisible()) {
+        hide();
+    }
+
+    deleteLater();
+}
